<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AboutDialog</name>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
</context>
<context>
    <name>AboutLabel</name>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Unable to launch external application.
</source>
        <translation>Невозможно запустить внешнее приложение.
</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>Assistant</name>
    <message>
        <source>Error registering documentation file &apos;%1&apos;: %2</source>
        <translation>Ошибка регистрации файла документации «%1»: %2</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Ошибка: %1</translation>
    </message>
    <message>
        <source>Could not register documentation file
%1

Reason:
%2</source>
        <translation>Не удалось зарегистрировать файл документации
%1

Причина:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully registered.</source>
        <translation>Документация успешно зарегистрирована.</translation>
    </message>
    <message>
        <source>Could not unregister documentation file
%1

Reason:
%2</source>
        <translation>Не удалось дерегистрировать файл документации
%1

Причина:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully unregistered.</source>
        <translation>Документация успешно дерегистрирована.</translation>
    </message>
    <message>
        <source>Error reading collection file &apos;%1&apos;: %2.</source>
        <translation>Ошибка чтения файла коллекции справки «%1»: %2.</translation>
    </message>
    <message>
        <source>Error creating collection file &apos;%1&apos;: %2.</source>
        <translation>Ошибка создания файла коллекции справки «%1»: %2.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>Не удалось загрузить драйвер баз данных sqlite!</translation>
    </message>
</context>
<context>
    <name>BookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Добавление закладки</translation>
    </message>
    <message>
        <source>Bookmark:</source>
        <translation>Закладка:</translation>
    </message>
    <message>
        <source>Add in Folder:</source>
        <translation>Добавить в папку:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Новая папка</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Переименовать папку</translation>
    </message>
</context>
<context>
    <name>BookmarkItem</name>
    <message>
        <source>New Folder</source>
        <translation>Новая папка</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Безымянная</translation>
    </message>
</context>
<context>
    <name>BookmarkManager</name>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>You are going to delete a Folder, this will also&lt;br&gt;remove it&apos;s content. Are you sure to continue?</source>
        <translation>Удаление папки приведёт к удалению её содержимого.&lt;br&gt;Желаете продолжить?</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Добавить закладку...</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Безымянная</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation>Управление закладками...</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Удалить папку</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Переименовать папку</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Открыть закладку</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Открыть закладку в новой вкладке</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Удалить закладку</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Переименовать закладку</translation>
    </message>
</context>
<context>
    <name>BookmarkManagerWidget</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>Управление закладками</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Поиск:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Import and Backup</source>
        <translation>Резервное копирование</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Import...</source>
        <translation>Импорт...</translation>
    </message>
    <message>
        <source>Export...</source>
        <translation>Экспорт...</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <source>Files (*.xbel)</source>
        <translation>Файлы (*.xbel)</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Unable to save bookmarks.</source>
        <translation>Невозможно сохранитьзакладки.</translation>
    </message>
    <message>
        <source>You are goingto delete a Folder, this will also&lt;br&gt; remove it&apos;s content. Are you sure to continue?</source>
        <translation>Удаление папки приведёт к удалению её содержимого.&lt;br&gt;Желаете продолжить?</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Удалить папку</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Переименовать папку</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Открыть закладку</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Открыть закладку в новой вкладке</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Удалить закладку</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Переименовать закладку</translation>
    </message>
</context>
<context>
    <name>BookmarkModel</name>
    <message>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Bookmarks Toolbar</source>
        <translation>Панель закладок</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Меню закладок</translation>
    </message>
</context>
<context>
    <name>BookmarkWidget</name>
    <message>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Фильтр:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>CentralWidget</name>
    <message>
        <source>Print Document</source>
        <translation>Печать документа</translation>
    </message>
</context>
<context>
    <name>CmdLineParser</name>
    <message>
        <source>Unknown option: %1</source>
        <translation>Неизвестный параметр: %1</translation>
    </message>
    <message>
        <source>Unknown widget: %1</source>
        <translation>Неизвестный виджет: %1</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; does not exist.</source>
        <translation>Файл коллекции справки «%1» не существует.</translation>
    </message>
    <message>
        <source>Usage: assistant [Options]

-collectionFile file       Uses the specified collection
                           file instead of the default one
-showUrl url               Shows the document with the
                           url.
-enableRemoteControl       Enables Assistant to be
                           remotely controlled.
-show widget               Shows the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-activate widget           Activates the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-hide widget               Hides the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; or &quot;search&quot;.
-register helpFile         Registers the specified help file
                           (.qch) in the given collection
                           file.
-unregister helpFile       Unregisters the specified help file
                           (.qch) from the give collection
                           file.
-setCurrentFilter filter   Set the filter as the active filter.
-remove-search-index       Removes the full text search index.
-rebuild-search-index      Re-builds the full text search index (potentially slow).
-quiet                     Does not display any error or
                           status message.
-help                      Displays this help.
</source>
        <translation>Использование: assistant [ОПЦИИ]

-collectionFile файл       Использовать указанный файл коллекции,
                           вместо стандартного
-showUrl ссылка            Отобразить документ по ссылке.
-enableRemoteControl       Включение удалённого управления Assistant.
-show панель               Отображение указанной панели,
                           которая может быть «contents», «index»,
                           «bookmarks» или «search».
-activate панель           Включение указанной панели,
                           которая может быть «contents», «index»,
                           «bookmarks» или «search».
-hide панель               Скрытие указанной панели,
                           которая может быть «contents», «index»,
                           «bookmarks» или «search».
-register файлСправки      Регистрация указанного файла справки (.qch)
                           в данном файле коллекции.
-unregister файлСправки    Отмена регистрации указанного файла
                           справки (.qch) в данном файле коллекции.
-setCurrentFilter фильтр   Активация указанного фильтра.
-remove-search-index       Удаление индекса полнотекстового поиска.
-rebuild-search-index      Пересоздание индекса полнотекстового поиска
                           (потенциально медленно).
-quiet                     Не отображать сообщения об ошибках и состояниях.
-help                      Показать эту справку.
</translation>
    </message>
    <message>
        <source>Missing collection file.</source>
        <translation>Отсутствует файл коллекции справки.</translation>
    </message>
    <message>
        <source>Invalid URL &apos;%1&apos;.</source>
        <translation>Некорректный URL «%1».</translation>
    </message>
    <message>
        <source>Missing URL.</source>
        <translation>Отсутствует URL.</translation>
    </message>
    <message>
        <source>Missing widget.</source>
        <translation>Отсутствует виджет.</translation>
    </message>
    <message>
        <source>The Qt help file &apos;%1&apos; does not exist.</source>
        <translation>Файл справки Qt «%1» не существует.</translation>
    </message>
    <message>
        <source>Missing help file.</source>
        <translation>Отсутствует файл справки.</translation>
    </message>
    <message>
        <source>Missing filter argument.</source>
        <translation>Отсутствует параметр фильтра.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Замечание</translation>
    </message>
</context>
<context>
    <name>ContentWindow</name>
    <message>
        <source>Open Link</source>
        <translation>Открыть ссылку</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Открыть ссылку в новой вкладке</translation>
    </message>
</context>
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <source>Add Filter Name</source>
        <translation>Добавление фильтра</translation>
    </message>
    <message>
        <source>Filter Name:</source>
        <translation>Название фильтра:</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <source>Previous</source>
        <translation>Предыдущее</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следующее</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Учитывать регистр символов</translation>
    </message>
    <message>
        <source>&lt;img src=&quot;:/qt-project.org/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Search wrapped</source>
        <translation>&lt;img src=&quot;:/qt-project.org/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Поиск с начала</translation>
    </message>
</context>
<context>
    <name>FontPanel</name>
    <message>
        <source>Font</source>
        <translation>Шрифт</translation>
    </message>
    <message>
        <source>&amp;Writing system</source>
        <translation>Система &amp;письма</translation>
    </message>
    <message>
        <source>&amp;Family</source>
        <translation>&amp;Шрифт</translation>
    </message>
    <message>
        <source>&amp;Style</source>
        <translation>&amp;Начертание</translation>
    </message>
    <message>
        <source>&amp;Point size</source>
        <translation>&amp;Размер</translation>
    </message>
</context>
<context>
    <name>GlobalActions</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Назад</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Вперёд</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation>&amp;Домой</translation>
    </message>
    <message>
        <source>ALT+Home</source>
        <translation>ALT+Home</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <translation>У&amp;величить</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <translation>У&amp;меньшить</translation>
    </message>
    <message>
        <source>&amp;Copy selected Text</source>
        <translation>&amp;Копировать выделенный текст</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Печать...</translation>
    </message>
    <message>
        <source>&amp;Find in Text...</source>
        <translation>П&amp;оиск в тексте...</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Поиск</translation>
    </message>
</context>
<context>
    <name>HelpEngineWrapper</name>
    <message>
        <source>Unfiltered</source>
        <translation>Вся документация</translation>
    </message>
</context>
<context>
    <name>HelpViewer</name>
    <message>
        <source>&lt;title&gt;about:blank&lt;/title&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;title&gt;Error 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;The page could not be found.&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</source>
        <translation>&lt;title&gt;Ошибка 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;Страница не найдена.&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;«%1»&lt;/h3&gt;&lt;/div&gt;</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Открыть ссылку</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>Копировать &amp;адрес ссылки</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Open Link in New Tab	Ctrl+LMB</source>
        <translation>Открыть ссылку в новой вкладке	Ctrl+LMB</translation>
    </message>
    <message>
        <source>Error 404...</source>
        <translation>Ошибка 404...</translation>
    </message>
    <message>
        <source>The page could not be found!</source>
        <translation>Не удалось найти страницу!</translation>
    </message>
    <message>
        <source>Please make sure that you have all documentation sets installed.</source>
        <translation>Убедитесь, что установлен весь набор документации.</translation>
    </message>
    <message>
        <source>Error loading: %1</source>
        <translation>Ошибка загрузки: %1</translation>
    </message>
    <message>
        <source>Open Link in New Page</source>
        <translation>Открыть ссылку в новой странице</translation>
    </message>
</context>
<context>
    <name>IndexWindow</name>
    <message>
        <source>&amp;Look for:</source>
        <translation>&amp;Искать:</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Открыть ссылку</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Открыть ссылку в новой вкладке</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Index</source>
        <translation>Указатель</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Содержание</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Looking for Qt Documentation...</source>
        <translation>Поиск документации Qt...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Page Set&amp;up...</source>
        <translation>Параметры &amp;страницы...</translation>
    </message>
    <message>
        <source>Print Preview...</source>
        <translation>Предпросмотр печати...</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Новая &amp;вкладка</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Закрыть вкладку</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Найти &amp;следующее</translation>
    </message>
    <message>
        <source>Find &amp;Previous</source>
        <translation>Найти &amp;предыдущее</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <source>Normal &amp;Size</source>
        <translation>Нормальный р&amp;азмер</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>ALT+C</source>
        <translation>ALT+C</translation>
    </message>
    <message>
        <source>ALT+I</source>
        <translation>ALT+I</translation>
    </message>
    <message>
        <source>ALT+O</source>
        <translation>ALT+O</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>ALT+S</source>
        <translation>ALT+S</translation>
    </message>
    <message>
        <source>&amp;Go</source>
        <translation>&amp;Перейти</translation>
    </message>
    <message>
        <source>Sync with Table of Contents</source>
        <translation>Синхронизировать с оглавлением</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхронизировать</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Следующая страница</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Right</source>
        <translation>Ctrl+Alt+Right</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Предыдущая страница</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Left</source>
        <translation>Ctrl+Alt+Left</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Закладки</translation>
    </message>
    <message>
        <source>Could not register file &apos;%1&apos;: %2</source>
        <translation>Не удалось зарегистрировать файл «%1»: %2</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <source>Open Pages</source>
        <translation>Открытые страницы</translation>
    </message>
    <message>
        <source>Bookmark Toolbar</source>
        <translation>Панель закладок</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>ALT+P</source>
        <translation>ALT+P</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <source>Navigation Toolbar</source>
        <translation>Панель навигации</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Окно</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Масштаб</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Свернуть</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>Панели инструментов</translation>
    </message>
    <message>
        <source>Filter Toolbar</source>
        <translation>Панель фильтров</translation>
    </message>
    <message>
        <source>Filtered by:</source>
        <translation>Отфильтровано по:</translation>
    </message>
    <message>
        <source>Address Toolbar</source>
        <translation>Панель адреса</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Адрес:</translation>
    </message>
    <message>
        <source>Could not find the associated content item.</source>
        <translation>Не удалось найти элемент, связанный с содержанием.</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;p&gt;Browser: %3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %4 The Qt Company Ltd.&lt;/p&gt;</source>
        <translation>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Версия %2&lt;/p&gt;&lt;p&gt;Обозреватель: %3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %4 The Qt Company Ltd.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <source>Updating search index</source>
        <translation>Обновление индекса полнотекстового поиска</translation>
    </message>
</context>
<context>
    <name>OpenPagesWidget</name>
    <message>
        <source>Close %1</source>
        <translation>Закрыть %1</translation>
    </message>
    <message>
        <source>Close All Except %1</source>
        <translation>Закрыть всё, кроме %1</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Add Documentation</source>
        <translation>Добавить документацию</translation>
    </message>
    <message>
        <source>Qt Compressed Help Files (*.qch)</source>
        <translation>Сжатые файлы справки Qt (*.qch)</translation>
    </message>
    <message>
        <source>The namespace %1 is already registered!</source>
        <translation>Пространство имён «%1» уже зарегистрировано!</translation>
    </message>
    <message>
        <source>The specified file is not a valid Qt Help File!</source>
        <translation>Указанный файл не является корректным файлом справки Qt!</translation>
    </message>
    <message>
        <source>Remove Documentation</source>
        <translation>Удалить документацию</translation>
    </message>
    <message>
        <source>Some documents currently opened in Assistant reference the documentation you are attempting to remove. Removing the documentation will close those documents.</source>
        <translation>Некоторые открытые в Qt Assistant документы ссылаются на документацию, которую вы пытаетесь удалить. Её удаление приведёт к закрытию этих документов.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>Использовать индивидуальные настройки</translation>
    </message>
</context>
<context>
    <name>PreferencesDialogClass</name>
    <message>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Шрифты</translation>
    </message>
    <message>
        <source>Font settings:</source>
        <translation>Настройки шрифта:</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Обозреватель</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Приложение</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Фильтры</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Фильтр:</translation>
    </message>
    <message>
        <source>Attributes:</source>
        <translation>Атрибуты:</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Документация</translation>
    </message>
    <message>
        <source>Registered Documentation:</source>
        <translation>Зарегистрированная документация:</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Добавить...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Стартовая страница</translation>
    </message>
    <message>
        <source>Current Page</source>
        <translation>Текущая страница</translation>
    </message>
    <message>
        <source>Restore to default</source>
        <translation>Страница по умолчанию</translation>
    </message>
    <message>
        <source>On help start:</source>
        <translation>При запуске:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Отобразить стартовую страницу</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Отобразить пустую страницу</translation>
    </message>
    <message>
        <source>Show my tabs from last session</source>
        <translation>Восстановить предыдущую сессиию</translation>
    </message>
    <message>
        <source>Blank Page</source>
        <translation>Пустая страница</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <source>Show tabs for each individual page</source>
        <translation>Показывать вкладки для каждой страницы</translation>
    </message>
</context>
<context>
    <name>RemoteControl</name>
    <message>
        <source>Debugging Remote Control</source>
        <translation>Отладочное удалённое управление</translation>
    </message>
    <message>
        <source>Received Command: %1 %2</source>
        <translation>Получена команда: %1 %2</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>Копировать &amp;адрес ссылки</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Открыть ссылку в новой вкладке</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Выделить всё</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>(Untitled)</source>
        <translation>(Без названия)</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Новая &amp;вкладка</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Закрыть вкладку</translation>
    </message>
    <message>
        <source>Close Other Tabs</source>
        <translation>Закрыть остальные вкладки</translation>
    </message>
    <message>
        <source>Add Bookmark for this Page...</source>
        <translation>Добавить закладку для этой страницы...</translation>
    </message>
</context>
<context>
    <name>TopicChooser</name>
    <message>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <source>Choose a topic for &lt;b&gt;%1&lt;/b&gt;:</source>
        <translation>Выберите раздел для &lt;b&gt;%1&lt;/b&gt;:</translation>
    </message>
    <message>
        <source>Choose Topic</source>
        <translation>Выбор раздела</translation>
    </message>
    <message>
        <source>&amp;Topics</source>
        <translation>&amp;Разделы</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Показать</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
</context>
</TS>
